@@ -1,7 +1,6 @@
-from .common import AuthResponse, BarrierToken
+from .common import AuthResponse, BearerToken
 from .local_account import LocalAccount
 from .auth_code import AuthCode
 from .user_info import UserInfo
 from .id_token_claims import IDTokenClaims
 from .auth_token import AuthToken
-from .msal_client_config import MSALClientConfig, MSALPolicies
